scipy.stats.rv_discrete
=======================

.. currentmodule:: scipy.stats

.. autoclass:: rv_discrete

   

   .. HACK
      .. autosummary::
         :toctree:
      
         rv_discrete.__init__
         rv_discrete.cdf
         rv_discrete.entropy
         rv_discrete.expect
         rv_discrete.freeze
         rv_discrete.interval
         rv_discrete.isf
         rv_discrete.logcdf
         rv_discrete.logpmf
         rv_discrete.logsf
         rv_discrete.mean
         rv_discrete.median
         rv_discrete.moment
         rv_discrete.pmf
         rv_discrete.ppf
         rv_discrete.rvs
         rv_discrete.sf
         rv_discrete.stats
         rv_discrete.std
         rv_discrete.var



   

